@@ -1,6 +1,5 @@
-/* Created by Ville-Petteri Makinen 2003-2010
-   Copyright (C) V-P Makinen
-   All rights reserved */
+/* Created by Ville-Petteri Makinen
+   email: ville.makinen@vipmak.net */
 
 #include "koho.local.h"
 
@@ -11,8 +10,8 @@ vector<string>
 Model::identities() const {
   ModelBuffer* p = (ModelBuffer*)buffer;
   vector<string> array;
-  unordered_map<string, Point>& points = p->points;
-  unordered_map<string, Point>::const_iterator it;
+  map<string, Point>& points = p->points;
+  map<string, Point>::const_iterator it;
   for(it = points.begin(); it != points.end(); it++)
     array.push_back(it->first);
   return array;
